This is the first python project that I created and shared with pypi. 
I like working with excel file - importing and exporting data and data transformation using VBA and M-Code.
This module is created to handle text file data by importing data for searching, adding data, inverting data and formatting data. 
Once the data is finalised, you can use "export_txt" function to convert it to text file.
I will work on adding more useful function later in future.
- Cheny Lioe -
